@@ -4,10 +4,16 @@ import subprocess
 import boto3
 import typer
 from github import Github
+from datetime import datetime
 
-from devolv.drift.aws_fetcher import get_aws_policy_document, merge_policy_documents, build_superset_policy
+from devolv.drift.aws_fetcher import (
+    get_aws_policy_document,
+    merge_policy_documents,
+    build_superset_policy,
+)
 from devolv.drift.issues import create_approval_issue, wait_for_sync_choice
 from devolv.drift.github_approvals import create_github_pr
+from devolv.drift.report import print_drift_diff
 
 app = typer.Typer()
 
@@ -33,7 +39,6 @@ def push_branch(branch_name: str):
         raise typer.Exit(1)
 
 def detect_drift(local_doc, aws_doc) -> bool:
-    """Detect removal drift: AWS has permissions missing from local (danger)."""
     local_statements = {json.dumps(s, sort_keys=True) for s in local_doc.get("Statement", [])}
     aws_statements = {json.dumps(s, sort_keys=True) for s in aws_doc.get("Statement", [])}
 
@@ -41,8 +46,6 @@ def detect_drift(local_doc, aws_doc) -> bool:
 
     if missing_in_local:
         typer.echo("❌ Drift detected: Local is missing permissions present in AWS.")
-        for stmt in missing_in_local:
-            typer.echo(stmt)
         return True
 
     typer.echo("✅ No removal drift detected (local may have extra permissions; that's fine).")
@@ -72,6 +75,9 @@ def drift(
     aws_doc = get_aws_policy_document(policy_arn)
     drift_detected = detect_drift(local_doc, aws_doc)
 
+    if drift_detected:
+        print_drift_diff(local_doc, aws_doc)
+
     if not drift_detected:
         _update_aws_policy(iam, policy_arn, local_doc)
         typer.echo(f"✅ AWS policy {policy_arn} updated to include any local additions.")
@@ -79,7 +85,6 @@ def drift(
             typer.echo("✅ No forced approval requested. Exiting.")
             return
 
-    # From here, we need approval flow
     repo_full_name = repo_full_name or os.getenv("GITHUB_REPOSITORY")
     token = os.getenv("GITHUB_TOKEN")
 
@@ -91,7 +96,13 @@ def drift(
         raise typer.Exit(1)
 
     assignees = [a.strip() for a in approvers.split(",") if a.strip()]
-    issue_num, _ = create_approval_issue(repo_full_name, token, policy_name, assignees=assignees)
+    
+    # 💡 Pass drift_detected to dynamically control issue body
+    issue_num, _ = create_approval_issue(
+        repo_full_name, token, policy_name, assignees=assignees, drift_detected=drift_detected
+    )
+    issue_url = f"https://github.com/{repo_full_name}/issues/{issue_num}"
+    typer.echo(f"✅ Approval issue created: {issue_url}")
 
     choice = wait_for_sync_choice(repo_full_name, issue_num, token)
 
@@ -109,6 +120,22 @@ def drift(
         typer.echo(f"✅ AWS policy {policy_arn} updated with superset of local + AWS.")
         _update_local_and_create_pr(superset_doc, policy_file, repo_full_name, policy_name, issue_num, token, "with superset of local + AWS")
 
+    elif choice == "accept":
+        typer.echo("✅ Approval received: no changes required. Closing issue.")
+        gh = Github(token)
+        repo = gh.get_repo(repo_full_name)
+        issue = repo.get_issue(number=issue_num)
+        issue.create_comment("✅ Approved current state. No action needed.")
+        issue.edit(state="closed")
+
+    elif choice == "reject":
+        typer.echo("❌ Approval rejected: no changes made. Closing issue.")
+        gh = Github(token)
+        repo = gh.get_repo(repo_full_name)
+        issue = repo.get_issue(number=issue_num)
+        issue.create_comment("❌ Rejected current state. No action taken.")
+        issue.edit(state="closed")
+
     else:
         typer.echo("⏭ No synchronization performed (skip).")
 
@@ -128,9 +155,13 @@ def _update_local_and_create_pr(doc, policy_file, repo_full_name, policy_name, i
     with open(policy_file, "w") as f:
         f.write(new_content)
 
+    timestamp = datetime.utcnow().strftime("%Y%m%d-%H%M%S")
     branch = (
-        f"{description.replace(' ', '-').replace('+', 'plus').replace('/', '-')}-policy-{policy_name}"
-        .strip("-")
+        f"drift-sync-{policy_name}-{timestamp}"
+        .replace(' ', '-')
+        .replace('+', 'plus')
+        .replace('/', '-')
+        .strip('-')
         .lower()
     )
 
