@@ -17,26 +17,48 @@ def _get_github_repo(repo_full_name: str):
     gh = Github(_get_github_token())
     return gh.get_repo(repo_full_name)
 
-def create_github_issue(repo: str, title: str, body: str, assignees: list) -> tuple:
+def create_github_issue(repo: str, policy_name: str, assignees: list, drift_detected: bool = True) -> tuple:
     """
-    Create a GitHub issue and return (number, url)
+    Create a GitHub issue with dynamic body based on drift_detected.
+    Returns (issue number, issue URL)
     """
     try:
         repo_obj = _get_github_repo(repo)
+        approver_list = ", ".join([f"@{a}" for a in assignees]) if assignees else "anyone"
+
+        title = f"Approval needed for IAM policy: {policy_name}"
+        if drift_detected:
+            body = (
+                f"Please review and approve the sync for `{policy_name}`.\n\n"
+                f"✅ **Allowed approvers:** {approver_list}\n\n"
+                "**Reply with one of the following commands to proceed:**\n"
+                "- `local->aws` → Apply local policy changes to AWS\n"
+                "- `aws->local` → Update local policy file from AWS\n"
+                "- `aws<->local` → Sync both ways (superset, update AWS + local)\n"
+                "- `skip` → Skip this sync"
+            )
+        else:
+            body = (
+                f"Please review and approve the current state for `{policy_name}` (✅ No drift detected).\n\n"
+                f"✅ **Allowed approvers:** {approver_list}\n\n"
+                "**Reply with one of the following commands to proceed:**\n"
+                "- `accept` → Approve the current state, no further action\n"
+                "- `reject` → Reject the current state (no changes will be made)"
+            )
+
         issue = repo_obj.create_issue(title=title, body=body, assignees=assignees)
         print(f"✅ Created issue #{issue.number} in {repo}: {issue.html_url}")
         return issue.number, issue.html_url
+
     except Exception as e:
         print(f"❌ Failed to create issue in {repo}: {e}")
         raise
 
 def create_github_pr(repo: str, head_branch: str, title: str, body: str, base: str = "main", issue_num: int = None) -> tuple:
     """
-    Create a GitHub PR. If issue_num is provided, comment on the issue.
-    Return (PR number, PR URL).
+    Create a GitHub PR. Optionally comments on linked issue.
+    Returns (PR number, PR URL)
     """
-    from github import Github
-
     try:
         repo_obj = _get_github_repo(repo)
         pr = repo_obj.create_pull(
@@ -45,35 +67,29 @@ def create_github_pr(repo: str, head_branch: str, title: str, body: str, base: s
             head=head_branch,
             base=base
         )
-        #print(f"✅ Created PR #{pr.number} in {repo}: {pr.html_url}")
 
         if issue_num:
             issue = repo_obj.get_issue(number=issue_num)
-            issue.create_comment(f"A PR has been created for this sync: {pr.html_url}")
-        
+            issue.create_comment(f"✅ PR created and linked: {pr.html_url}")
+
+        print(f"✅ Created PR #{pr.number} in {repo}: {pr.html_url}")
         return pr.number, pr.html_url
 
     except Exception as e:
-        print(f"❌ Failed to create PR: {e}")
+        print(f"❌ Failed to create PR in {repo}: {e}")
         raise
 
 def push_branch(branch_name: str):
-    import subprocess
-    import typer
-
+    """
+    Create, commit to, and push a git branch, rebasing if needed.
+    """
     try:
-        # Create or switch to branch safely
         subprocess.run(["git", "checkout", "-B", branch_name], check=True)
-
-        # Ensure Git identity is set
         subprocess.run(["git", "config", "user.email", "github-actions@users.noreply.github.com"], check=True)
         subprocess.run(["git", "config", "user.name", "github-actions"], check=True)
-
-        # Add, commit
         subprocess.run(["git", "add", "."], check=True)
         subprocess.run(["git", "commit", "-m", f"Update policy: {branch_name}"], check=True)
 
-        # Try pushing
         try:
             subprocess.run(["git", "push", "--set-upstream", "origin", branch_name], check=True)
         except subprocess.CalledProcessError:
@@ -86,5 +102,3 @@ def push_branch(branch_name: str):
     except subprocess.CalledProcessError as e:
         typer.echo(f"❌ Git command failed: {e}")
         raise typer.Exit(1)
-
-
